@@ -17,17 +17,15 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <QDebug>
-#include <QSettings>
-#include <QDeclarativeView>
-#include <QtDeclarative/QDeclarativeContext>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusAbstractAdaptor>
-#include <QtDBus/QDBusInterface>
-
 #include <sys/types.h>
 #include <sys/socket.h>
 
+#include <QSettings>
+#include <QDebug>
+#include <QQmlContext>
+#include <QDBusConnection>
+#include <libintl.h>
+
 #include "main_model.h"
 #include "candidate_word.h"
 #include "main_controller.h"
@@ -57,7 +55,7 @@ void MainController::loadCfg()
     settings->beginGroup("base");
     mIsHorizontal = !settings->value("VerticalList", false).toBool();
     qDebug() << "mIsHorizontal:" << mIsHorizontal;
-    mSkinName = settings->value("CurtSkinType", "ubuntukylin-dark1").toString();
+    mSkinName = settings->value("CurtSkinType", "ubuntu-orange").toString();
     qDebug() << "mSkinName:" << mSkinName;
     settings->endGroup();
     delete settings;
@@ -70,18 +68,16 @@ void MainController::init()
     qmlRegisterType<CandidateWord>();
 
     mTopLevel = new TopLevel;
-    mView = new QDeclarativeView;
+    mView = new QQuickWidget;
     mModel = MainModel::self();
     mModel->setIsHorizontal(mIsHorizontal);
 
     mSkinBase = new SkinBase;
 
     mTopLevel->setCenterWidget(mView);
-
+    mView->setClearColor(Qt::transparent);
     mView->setContentsMargins(0, 0, 0, 0);
-    mView->setResizeMode(QDeclarativeView::SizeViewToRootObject);
-    mView->setResizeAnchor(QGraphicsView::AnchorViewCenter);
-    mView->viewport()->setAutoFillBackground(false);
+    mView->setResizeMode(QQuickWidget::SizeViewToRootObject);
     mView->rootContext()->setContextProperty("mainCtrl", this);
     mView->rootContext()->setContextProperty("mainModel", mModel);
     mView->rootContext()->setContextProperty("mainSkin", mSkinBase);
@@ -222,12 +218,16 @@ void MainController::setSkinName(QString skinName)
 
 void MainController::updateProperty(const KimpanelProperty &prop)
 {
-    if (tr("No input window") == prop.label) {
+    if (gettext("No input window") == prop.label) {
         QIcon icon = QIcon::fromTheme("fcitx");
         mSystemTray->setIcon(icon);
         return;
     }
-    QIcon icon = QIcon::fromTheme(prop.icon, QIcon::fromTheme("fcitx-kbd"));
+   QIcon icon;
+   if(prop.icon=="fcitx-kbd" || prop.icon==""|| prop.icon.indexOf("indicator-keyboard")!=-1)
+               icon = QIcon::fromTheme("fcitx-kbd");
+   else
+         icon = QIcon::fromTheme(prop.icon, QIcon::fromTheme("fcitx-kbd"));
     mSystemTray->setIcon(icon);
     mModel->resetData();
 }
