@@ -28,15 +28,6 @@
 #include <sys/wait.h>
 
 #include "config.h"
-#include "skin/skinmenu.h"
-
-enum ExecMenuType
-{
-    nullExecMenuType,
-    updateVKListMenu,
-    updateIMListMenu,
-    //updateThemerMenu,
-};
 
 class SystemTrayMenu : public QMenu
 {
@@ -47,13 +38,12 @@ public:
     virtual ~SystemTrayMenu();
     void init();
 
+private:
+    void updateMainMenu();
+
 private slots:
-    void triggerUpdateMainMenu();
     void triggerUpdateVKListMenu();
     void triggerUpdateIMListMenu();
-#ifdef ENABLE_UK_SYNC
-    void triggerUpdateSyncMenu();
-#endif
     void menuItemOnClick(QAction* action);
 
 private:
@@ -64,33 +54,29 @@ public slots:
     void updateProperty(const KimpanelProperty &prop);
 
 private:
+    //return True if is the fcitx-kbd checked.
+    bool doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list);
     void doUpdateVKListMenu(const QList<KimpanelProperty> &prop_list);
-    void doUpdateIMListMenu(const QList<KimpanelProperty> &prop_list);
-    void appendIMListToMenu(QMenu *menu, const QList<KimpanelProperty> &prop_list);
     void startChildApp(const char *app_exe, const char * const argv[] = NULL);
-#ifdef ENABLE_UK_SYNC
-    void syncConfigUp();
-    void syncConfigDown();
-#endif	
 public:
     void restart();
 
 private:
     static bool isUnity();
+    static bool isIMList(const QString &key);
+    static bool isVKList(const QString &key);
 
 private:
     QString mCurtIMLabel;
     //前两个用不到，见后端KimpanelRegisterAllStatus()函数
 #define StatusMenuSkip (2)
     QList<KimpanelProperty> mIMList;
+    QList<KimpanelProperty> mVKList;
     QList<KimpanelProperty> mStatusMenuList;
-    SkinMenu *mSkinMenu;
-    QMenu *mVKListMenu;
-    QMenu *mIMListMenu;
-#ifdef ENABLE_UK_SYNC
-    QMenu *mSyncMenu;
-#endif
-    ExecMenuType mExecMenuType;
+
+private:
+    void skinMenuItemOnClick(QAction* action);
+    void doUpdateSkinListMenu();
 };
 
 #endif // __SYSTEM_TRAY_MENU_H__
